#[non_exhaustive]pub struct UpdateWorkGroupInput {
pub work_group: Option<String>,
pub description: Option<String>,
pub configuration_updates: Option<WorkGroupConfigurationUpdates>,
pub state: Option<WorkGroupState>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.work_group: Option<String>The specified workgroup that will be updated.
description: Option<String>The workgroup description.
configuration_updates: Option<WorkGroupConfigurationUpdates>Contains configuration updates for an Athena SQL workgroup.
state: Option<WorkGroupState>The workgroup state that will be updated for the given workgroup.
Implementations
Sourceimpl UpdateWorkGroupInput
impl UpdateWorkGroupInput
Sourcepub fn work_group(&self) -> Option<&str>
pub fn work_group(&self) -> Option<&str>
The specified workgroup that will be updated.
Sourcepub fn description(&self) -> Option<&str>
pub fn description(&self) -> Option<&str>
The workgroup description.
Sourcepub fn configuration_updates(&self) -> Option<&WorkGroupConfigurationUpdates>
pub fn configuration_updates(&self) -> Option<&WorkGroupConfigurationUpdates>
Contains configuration updates for an Athena SQL workgroup.
Sourcepub fn state(&self) -> Option<&WorkGroupState>
pub fn state(&self) -> Option<&WorkGroupState>
The workgroup state that will be updated for the given workgroup.
Sourceimpl UpdateWorkGroupInput
impl UpdateWorkGroupInput
Sourcepub fn builder() -> UpdateWorkGroupInputBuilder
pub fn builder() -> UpdateWorkGroupInputBuilder
Creates a new builder-style object to manufacture UpdateWorkGroupInput.